@@ -53,6 +53,9 @@ FAILEDOPERATION_DELETEUSERFAILED = 'FailedOperation.DeleteUserFailed'
 # Failed to unassociate the security group.
 FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.DisassociateSecurityGroupsFailed'
 
+# Failed to query the security group details
+FAILEDOPERATION_GETSECURITYGROUPDETAILFAILED = 'FailedOperation.GetSecurityGroupDetailFailed'
+
 # Refund is not supported for the instance
 FAILEDOPERATION_INSTANCECANNOTRETURN = 'FailedOperation.InstanceCanNotReturn'
 
@@ -62,9 +65,15 @@ FAILEDOPERATION_INSTANCERETURNFAILED = 'FailedOperation.InstanceReturnFailed'
 # Failed to modify account permissions.
 FAILEDOPERATION_MODIFYRIGHTFAILED = 'FailedOperation.ModifyRightFailed'
 
+# Failed to isolate the instance
+FAILEDOPERATION_OSSISOLATEINSTANCEFAILED = 'FailedOperation.OssIsolateInstanceFailed'
+
 # Failed to request the backend API.
 FAILEDOPERATION_OSSOPERATIONFAILED = 'FailedOperation.OssOperationFailed'
 
+# Failed to make order payment.
+FAILEDOPERATION_PAYFAILED = 'FailedOperation.PayFailed'
+
 # Failed to reset the account password.
 FAILEDOPERATION_RESETPASSWORDFAILED = 'FailedOperation.ResetPasswordFailed'
 
@@ -74,12 +83,18 @@ FAILEDOPERATION_SGCHANGEVIP = 'FailedOperation.SGChangeVip'
 # Failed to set a rule.
 FAILEDOPERATION_SETRULELOCATIONFAILED = 'FailedOperation.SetRuleLocationFailed'
 
+# Failed to publish security group rules
+FAILEDOPERATION_SETSVCLOCATIONFAILED = 'FailedOperation.SetSvcLocationFailed'
+
 # Either tag key/value verification or tag API authentication failed.
 FAILEDOPERATION_TAGDRYRUNERROR = 'FailedOperation.TagDryRunError'
 
 # Failed to update the security group information of an instance.
 FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFailed'
 
+# Unauthenticated user
+FAILEDOPERATION_USERNOTAUTHED = 'FailedOperation.UserNotAuthed'
+
 # VIP can’t be the same.
 FAILEDOPERATION_VIPNOTCHANGE = 'FailedOperation.VipNotChange'
 
@@ -95,6 +110,9 @@ INTERNALERROR = 'InternalError'
 # CAM authentication request failed.
 INTERNALERROR_CAMAUTHFAILED = 'InternalError.CamAuthFailed'
 
+# Failed to verify the VIP status
+INTERNALERROR_CHECKVIPSTATUSFAILED = 'InternalError.CheckVipStatusFailed'
+
 # Invalid COS address configuration.
 INTERNALERROR_COSCONFIGURATION = 'InternalError.CosConfiguration'
 
@@ -143,6 +161,9 @@ INTERNALERROR_GETTABLEINFOFAILED = 'InternalError.GetTableInfoFailed'
 # Failed to get the account list.
 INTERNALERROR_GETUSERLISTFAILED = 'InternalError.GetUserListFailed'
 
+# Failed to get the number of security groups
+INTERNALERROR_GETUSERSGCOUNTFAILED = 'InternalError.GetUserSGCountFailed'
+
 # Failed to query the security group quota of the user.
 INTERNALERROR_GETUSGQUOTAERROR = 'InternalError.GetUsgQuotaError'
 
@@ -185,6 +206,9 @@ INTERNALERROR_QUERYDATABASEFAILED = 'InternalError.QueryDatabaseFailed'
 # Failed to query the order information.
 INTERNALERROR_QUERYORDERFAILED = 'InternalError.QueryOrderFailed'
 
+# Failed to query the price
+INTERNALERROR_QUERYPRICEFAILED = 'InternalError.QueryPriceFailed'
+
 # An error occurred when reading data from the database.
 INTERNALERROR_READDATABASEFAILED = 'InternalError.ReadDatabaseFailed'
 
@@ -239,6 +263,9 @@ INVALIDPARAMETER_SGCHECKFAIL = 'InvalidParameter.SGCheckFail'
 # The instance shard does not exist.
 INVALIDPARAMETER_SHARDRESOURCEIDNOTFOUND = 'InvalidParameter.ShardResourceIdNotFound'
 
+# No purchasable specifications found
+INVALIDPARAMETER_SPECNOTFOUND = 'InvalidParameter.SpecNotFound'
+
 # The specified VPC subnet was not found.
 INVALIDPARAMETER_SUBNETNOTFOUND = 'InvalidParameter.SubnetNotFound'
 
@@ -269,6 +296,9 @@ INVALIDPARAMETERVALUE_BADUSERRIGHT = 'InvalidParameterValue.BadUserRight'
 # Invalid account type.
 INVALIDPARAMETERVALUE_BADUSERTYPE = 'InvalidParameterValue.BadUserType'
 
+# The number of products exceeds the upper limit.
+INVALIDPARAMETERVALUE_ILLEGALCOUNT = 'InvalidParameterValue.IllegalCount'
+
 # The dedicated cluster to which the database instance belongs was not found.
 INVALIDPARAMETERVALUE_ILLEGALEXCLUSTERID = 'InvalidParameterValue.IllegalExclusterID'
 
@@ -317,7 +347,7 @@ RESOURCEUNAVAILABLE_INSTANCEHASBEENLOCKED = 'ResourceUnavailable.InstanceHasBeen
 # Incorrect database instance status. Operations are not allowed.
 RESOURCEUNAVAILABLE_INSTANCESTATUSABNORMAL = 'ResourceUnavailable.InstanceStatusAbnormal'
 
-# 
+# Failed to verify the security group
 RESOURCEUNAVAILABLE_SGCHECKFAIL = 'ResourceUnavailable.SGCheckFail'
 
 # You have no permission to manipulate this API or resource.
